@@ -17,6 +17,7 @@ package prometheus
 import (
 	"fmt"
 	"reflect"
+	"strings"
 	"testing"
 
 	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
@@ -185,6 +186,14 @@ func TestStatefulSetVolumeInitial(t *testing.T) {
 									MountPath: "/etc/prometheus/config_out",
 									SubPath:   "",
 								},
+								{
+									Name:             "tls-assets",
+									ReadOnly:         true,
+									MountPath:        "/etc/prometheus/certs",
+									SubPath:          "",
+									MountPropagation: nil,
+									SubPathExpr:      "",
+								},
 								{
 									Name:      "prometheus-volume-init-test-db",
 									ReadOnly:  false,
@@ -215,6 +224,14 @@ func TestStatefulSetVolumeInitial(t *testing.T) {
 								},
 							},
 						},
+						{
+							Name: "tls-assets",
+							VolumeSource: v1.VolumeSource{
+								Secret: &v1.SecretVolumeSource{
+									SecretName: tlsAssetsSecretName("volume-init-test"),
+								},
+							},
+						},
 						{
 							Name: "config-out",
 							VolumeSource: v1.VolumeSource{
@@ -382,12 +399,42 @@ func TestListenLocal(t *testing.T) {
 		t.Fatal("Prometheus not listening on loopback when it should.")
 	}
 
-	if sset.Spec.Template.Spec.Containers[0].ReadinessProbe != nil {
-		t.Fatal("Prometheus readiness probe expected to be empty")
+	actualReadinessProbe := sset.Spec.Template.Spec.Containers[0].ReadinessProbe
+	expectedReadinessProbe := &v1.Probe{
+		Handler: v1.Handler{
+			Exec: &v1.ExecAction{
+				Command: []string{
+					`sh`,
+					`-c`,
+					`if [ -x "$(command -v curl)" ]; then curl http://localhost:9090/-/ready; elif [ -x "$(command -v wget)" ]; then wget -q http://localhost:9090/-/ready; else exit 1; fi`,
+				},
+			},
+		},
+		TimeoutSeconds:   3,
+		PeriodSeconds:    5,
+		FailureThreshold: 120,
+	}
+	if !reflect.DeepEqual(actualReadinessProbe, expectedReadinessProbe) {
+		t.Fatalf("Readiness probe doesn't match expected. \n\nExpected: %+v\n\nGot: %+v", expectedReadinessProbe, actualReadinessProbe)
 	}
 
-	if sset.Spec.Template.Spec.Containers[0].LivenessProbe != nil {
-		t.Fatal("Prometheus readiness probe expected to be empty")
+	actualLivenessProbe := sset.Spec.Template.Spec.Containers[0].LivenessProbe
+	expectedLivenessProbe := &v1.Probe{
+		Handler: v1.Handler{
+			Exec: &v1.ExecAction{
+				Command: []string{
+					`sh`,
+					`-c`,
+					`if [ -x "$(command -v curl)" ]; then curl http://localhost:9090/-/healthy; elif [ -x "$(command -v wget)" ]; then wget -q http://localhost:9090/-/healthy; else exit 1; fi`,
+				},
+			},
+		},
+		TimeoutSeconds:   3,
+		PeriodSeconds:    5,
+		FailureThreshold: 6,
+	}
+	if !reflect.DeepEqual(actualLivenessProbe, expectedLivenessProbe) {
+		t.Fatalf("Liveness probe doesn't match expected. \n\nExpected: %v\n\nGot: %v", expectedLivenessProbe, actualLivenessProbe)
 	}
 
 	if len(sset.Spec.Template.Spec.Containers[0].Ports) != 0 {
@@ -569,6 +616,31 @@ func TestThanosResourcesSet(t *testing.T) {
 	}
 }
 
+func TestThanosNoObjectStorage(t *testing.T) {
+	sset, err := makeStatefulSet(monitoringv1.Prometheus{
+		Spec: monitoringv1.PrometheusSpec{
+			Thanos: &monitoringv1.ThanosSpec{},
+		},
+	}, defaultTestConfig, nil, "")
+	if err != nil {
+		t.Fatalf("Unexpected error while making StatefulSet: %v", err)
+	}
+
+	if sset.Spec.Template.Spec.Containers[0].Name != "prometheus" {
+		t.Fatalf("expected 1st containers to be prometheus, got %s", sset.Spec.Template.Spec.Containers[0].Name)
+	}
+
+	if sset.Spec.Template.Spec.Containers[2].Name != "thanos-sidecar" {
+		t.Fatalf("expected 3rd containers to be thanos-sidecar, got %s", sset.Spec.Template.Spec.Containers[2].Name)
+	}
+
+	for _, arg := range sset.Spec.Template.Spec.Containers[0].Args {
+		if strings.HasPrefix(arg, "--storage.tsdb.max-block-duration=2h") {
+			t.Fatal("Prometheus compaction should be enabled")
+		}
+	}
+}
+
 func TestThanosObjectStorage(t *testing.T) {
 	testKey := "thanos-config-secret-test"
 
@@ -585,11 +657,20 @@ func TestThanosObjectStorage(t *testing.T) {
 		t.Fatalf("Unexpected error while making StatefulSet: %v", err)
 	}
 
+	if sset.Spec.Template.Spec.Containers[0].Name != "prometheus" {
+		t.Fatalf("expected 1st containers to be prometheus, got %s", sset.Spec.Template.Spec.Containers[0].Name)
+	}
+
+	if sset.Spec.Template.Spec.Containers[2].Name != "thanos-sidecar" {
+		t.Fatalf("expected 3rd containers to be thanos-sidecar, got %s", sset.Spec.Template.Spec.Containers[2].Name)
+	}
+
 	var containsEnvVar bool
 	for _, env := range sset.Spec.Template.Spec.Containers[2].Env {
 		if env.Name == "OBJSTORE_CONFIG" {
 			if env.ValueFrom.SecretKeyRef.Key == testKey {
 				containsEnvVar = true
+				break
 			}
 		}
 	}
@@ -597,15 +678,31 @@ func TestThanosObjectStorage(t *testing.T) {
 		t.Fatalf("Thanos sidecar is missing expected OBJSTORE_CONFIG env var with correct value")
 	}
 
-	var containsArg bool
-	const expectedArg = "--objstore.config=$(OBJSTORE_CONFIG)"
-	for _, arg := range sset.Spec.Template.Spec.Containers[2].Args {
-		if arg == expectedArg {
-			containsArg = true
+	{
+		var containsArg bool
+		const expectedArg = "--objstore.config=$(OBJSTORE_CONFIG)"
+		for _, arg := range sset.Spec.Template.Spec.Containers[2].Args {
+			if arg == expectedArg {
+				containsArg = true
+				break
+			}
+		}
+		if !containsArg {
+			t.Fatalf("Thanos sidecar is missing expected argument: %s", expectedArg)
 		}
 	}
-	if !containsArg {
-		t.Fatalf("Thanos sidecar is missing expected argument: %s", expectedArg)
+	{
+		var containsArg bool
+		const expectedArg = "--storage.tsdb.max-block-duration=2h"
+		for _, arg := range sset.Spec.Template.Spec.Containers[0].Args {
+			if arg == expectedArg {
+				containsArg = true
+				break
+			}
+		}
+		if !containsArg {
+			t.Fatalf("Prometheus is missing expected argument: %s", expectedArg)
+		}
 	}
 }
 
@@ -849,6 +946,33 @@ func TestWALCompression(t *testing.T) {
 	}
 }
 
+func TestThanosListenLocal(t *testing.T) {
+	sset, err := makeStatefulSet(monitoringv1.Prometheus{
+		Spec: monitoringv1.PrometheusSpec{
+			Thanos: &monitoringv1.ThanosSpec{
+				ListenLocal: true,
+			},
+		},
+	}, defaultTestConfig, nil, "")
+	if err != nil {
+		t.Fatalf("Unexpected error while making StatefulSet: %v", err)
+	}
+	foundGrpcFlag := false
+	foundHTTPFlag := false
+	for _, flag := range sset.Spec.Template.Spec.Containers[2].Args {
+		if flag == "--grpc-address=127.0.0.1:10901" {
+			foundGrpcFlag = true
+		}
+		if flag == "--http-address=127.0.0.1:10902" {
+			foundHTTPFlag = true
+		}
+	}
+
+	if !foundGrpcFlag || !foundHTTPFlag {
+		t.Fatal("Thanos not listening on loopback when it should.")
+	}
+}
+
 func TestTerminationPolicy(t *testing.T) {
 	sset, err := makeStatefulSet(monitoringv1.Prometheus{Spec: monitoringv1.PrometheusSpec{}}, defaultTestConfig, nil, "")
 	if err != nil {
